@@ -22,9 +22,12 @@ else:
 __all__ = (
     "AnomalySeverityType",
     "AnomalyStatusType",
+    "AnomalyTypeType",
+    "CloudWatchMetricDataStatusCodeType",
     "CloudWatchMetricsStatType",
     "CostEstimationServiceResourceStateType",
     "CostEstimationStatusType",
+    "DescribeOrganizationResourceCollectionHealthPaginatorName",
     "DescribeResourceCollectionHealthPaginatorName",
     "EventClassType",
     "EventDataSourceType",
@@ -38,11 +41,14 @@ __all__ = (
     "ListEventsPaginatorName",
     "ListInsightsPaginatorName",
     "ListNotificationChannelsPaginatorName",
+    "ListOrganizationInsightsPaginatorName",
     "ListRecommendationsPaginatorName",
     "LocaleType",
     "OptInStatusType",
+    "OrganizationResourceCollectionTypeType",
     "ResourceCollectionTypeType",
     "SearchInsightsPaginatorName",
+    "SearchOrganizationInsightsPaginatorName",
     "ServiceNameType",
     "UpdateResourceCollectionActionType",
     "ServiceName",
@@ -52,11 +58,16 @@ __all__ = (
 
 AnomalySeverityType = Literal["HIGH", "LOW", "MEDIUM"]
 AnomalyStatusType = Literal["CLOSED", "ONGOING"]
+AnomalyTypeType = Literal["CAUSAL", "CONTEXTUAL"]
+CloudWatchMetricDataStatusCodeType = Literal["Complete", "InternalError", "PartialData"]
 CloudWatchMetricsStatType = Literal[
     "Average", "Maximum", "Minimum", "SampleCount", "Sum", "p50", "p90", "p99"
 ]
 CostEstimationServiceResourceStateType = Literal["ACTIVE", "INACTIVE"]
 CostEstimationStatusType = Literal["COMPLETED", "ONGOING"]
+DescribeOrganizationResourceCollectionHealthPaginatorName = Literal[
+    "describe_organization_resource_collection_health"
+]
 DescribeResourceCollectionHealthPaginatorName = Literal["describe_resource_collection_health"]
 EventClassType = Literal[
     "CONFIG_CHANGE", "DEPLOYMENT", "INFRASTRUCTURE", "SCHEMA_CHANGE", "SECURITY_CHANGE"
@@ -78,6 +89,7 @@ ListAnomaliesForInsightPaginatorName = Literal["list_anomalies_for_insight"]
 ListEventsPaginatorName = Literal["list_events"]
 ListInsightsPaginatorName = Literal["list_insights"]
 ListNotificationChannelsPaginatorName = Literal["list_notification_channels"]
+ListOrganizationInsightsPaginatorName = Literal["list_organization_insights"]
 ListRecommendationsPaginatorName = Literal["list_recommendations"]
 LocaleType = Literal[
     "DE_DE",
@@ -93,8 +105,12 @@ LocaleType = Literal[
     "ZH_TW",
 ]
 OptInStatusType = Literal["DISABLED", "ENABLED"]
-ResourceCollectionTypeType = Literal["AWS_CLOUD_FORMATION", "AWS_SERVICE"]
+OrganizationResourceCollectionTypeType = Literal[
+    "AWS_ACCOUNT", "AWS_CLOUD_FORMATION", "AWS_SERVICE", "AWS_TAGS"
+]
+ResourceCollectionTypeType = Literal["AWS_CLOUD_FORMATION", "AWS_SERVICE", "AWS_TAGS"]
 SearchInsightsPaginatorName = Literal["search_insights"]
+SearchOrganizationInsightsPaginatorName = Literal["search_organization_insights"]
 ServiceNameType = Literal[
     "API_GATEWAY",
     "APPLICATION_ELB",
@@ -132,10 +148,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -150,6 +168,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -204,6 +223,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -225,6 +245,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -251,6 +272,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -264,6 +286,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -309,7 +332,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -338,11 +363,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -352,6 +379,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -409,9 +437,11 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
 PaginatorName = Literal[
+    "describe_organization_resource_collection_health",
     "describe_resource_collection_health",
     "get_cost_estimation",
     "get_resource_collection",
@@ -419,6 +449,8 @@ PaginatorName = Literal[
     "list_events",
     "list_insights",
     "list_notification_channels",
+    "list_organization_insights",
     "list_recommendations",
     "search_insights",
+    "search_organization_insights",
 ]
